@@ -1,11 +1,17 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2007, 2009 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2008 Craig Edwards <craigedwards@brainbox.cc>
- *   Copyright (C) 2006-2008 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2006 Oliver Lupton <oliverlupton@gmail.com>
+ *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
+ *   Copyright (C) 2018 Chris Novakovic <chrisnovakovic@users.noreply.github.com>
+ *   Copyright (C) 2013-2014, 2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
+ *   Copyright (C) 2012-2014, 2016-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
+ *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
+ *   Copyright (C) 2007-2008 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2007-2008 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -89,6 +95,8 @@ class CoreExport ConfigTag : public refcountbase
 class ServerLimits
 {
  public:
+	/** Maximum line length */
+	size_t MaxLine;
 	/** Maximum nickname length */
 	size_t NickMax;
 	/** Maximum channel length */
@@ -107,8 +115,6 @@ class ServerLimits
 	size_t MaxReal;
 	/** Maximum away message length */
 	size_t MaxAway;
-	/** Maximum line length */
-	size_t MaxLine;
 	/** Maximum hostname length */
 	size_t MaxHost;
 
@@ -160,12 +166,13 @@ struct CommandLineConf
 	 */
 	bool writepid;
 
-	/** Saved argc from startup
-	 */
+	/* Whether the --runasroot option was specified at boot. */
+	bool runasroot;
+
+	/** Saved argc from startup. */
 	int argc;
 
-	/** Saved argv from startup
-	 */
+	/** Saved argv from startup. */
 	char** argv;
 };
 
@@ -181,6 +188,9 @@ class CoreExport OperInfo : public refcountbase
 	/** Allowed channel modes from oper classes. */
 	std::bitset<64> AllowedChanModes;
 
+	/** Allowed snomasks from oper classes. */
+	std::bitset<64> AllowedSnomasks;
+
 	/** \<oper> block used for this oper-up. May be NULL. */
 	reference<ConfigTag> oper_block;
 	/** \<type> block used for this oper-up. Valid for local users, may be NULL on remote */
@@ -303,12 +313,12 @@ class CoreExport ServerConfig
 	CommandLineConf cmdline;
 
 	/** Clones CIDR range for ipv4 (0-32)
-	 * Defaults to 32 (checks clones on all IPs seperately)
+	 * Defaults to 32 (checks clones on all IPs separately)
 	 */
 	unsigned char c_ipv4_range;
 
 	/** Clones CIDR range for ipv6 (0-128)
-	 * Defaults to 128 (checks on all IPs seperately)
+	 * Defaults to 128 (checks on all IPs separately)
 	 */
 	unsigned char c_ipv6_range;
 
@@ -322,7 +332,7 @@ class CoreExport ServerConfig
 	std::string XLineMessage;
 
 	/* Holds the network name the local server
-	 * belongs to. This is an arbitary field defined
+	 * belongs to. This is an arbitrary field defined
 	 * by the administrator.
 	 */
 	std::string Network;
