@@ -1,10 +1,14 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2013-2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012-2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2004-2006, 2008 Craig Edwards <craigedwards@brainbox.cc>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
+ *   Copyright (C) 2007-2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -133,7 +137,7 @@ class CoreExport ModeHandler : public ServiceProvider
 	 * inside the mode parser as in the 1.0 api,
 	 * so the only use of this value (along with
 	 * IsListMode()) is for the core to determine
-	 * wether your module can produce 'lists' or not
+	 * whether your module can produce 'lists' or not
 	 * (e.g. banlists, etc)
 	 */
 	bool list;
@@ -159,7 +163,7 @@ class CoreExport ModeHandler : public ServiceProvider
 
  public:
 	/**
-	 * The constructor for ModeHandler initalizes the mode handler.
+	 * The constructor for ModeHandler initializes the mode handler.
 	 * The constructor of any class you derive from ModeHandler should
 	 * probably call this constructor with the parameters set correctly.
 	 * @param me The module which created this mode
@@ -289,7 +293,7 @@ class CoreExport ModeHandler : public ServiceProvider
 	/**
 	 * If your mode is a listmode, this method will be called to display an empty list (just the end of list numeric)
 	 * @param user The user issuing the command
-	 * @param channel The channel tehy're requesting an item list of (e.g. a banlist, or an exception list etc)
+	 * @param channel The channel they're requesting an item list of (e.g. a banlist, or an exception list etc)
 	 */
 	virtual void DisplayEmptyList(User* user, Channel* channel);
 
@@ -307,7 +311,7 @@ class CoreExport ModeHandler : public ServiceProvider
 
 	/**
 	 * When a MODETYPE_USER mode handler is being removed, the core will call this method for every user on the server.
-	 * The usermode will be removed using the appropiate server mode using InspIRCd::SendMode().
+	 * The usermode will be removed using the appropriate server mode using InspIRCd::SendMode().
 	 * @param user The user which the server wants to remove your mode from
 	 */
 	void RemoveMode(User* user);
@@ -451,8 +455,12 @@ class CoreExport PrefixMode : public ModeHandler
 class CoreExport SimpleUserModeHandler : public ModeHandler
 {
  public:
-	SimpleUserModeHandler(Module* Creator, const std::string& Name, char modeletter)
-		: ModeHandler(Creator, Name, modeletter, PARAM_NONE, MODETYPE_USER) {}
+	SimpleUserModeHandler(Module* Creator, const std::string& Name, char modeletter, bool operonly = false)
+		: ModeHandler(Creator, Name, modeletter, PARAM_NONE, MODETYPE_USER)
+	{
+		oper = operonly;
+	}
+
 	ModeAction OnModeChange(User* source, User* dest, Channel* channel, std::string& parameter, bool adding) CXX11_OVERRIDE;
 };
 
@@ -464,8 +472,12 @@ class CoreExport SimpleUserModeHandler : public ModeHandler
 class CoreExport SimpleChannelModeHandler : public ModeHandler
 {
  public:
-	SimpleChannelModeHandler(Module* Creator, const std::string& Name, char modeletter)
-		: ModeHandler(Creator, Name, modeletter, PARAM_NONE, MODETYPE_CHANNEL) {}
+	SimpleChannelModeHandler(Module* Creator, const std::string& Name, char modeletter, bool operonly = false)
+		: ModeHandler(Creator, Name, modeletter, PARAM_NONE, MODETYPE_CHANNEL)
+	{
+		oper = operonly;
+	}
+
 	ModeAction OnModeChange(User* source, User* dest, Channel* channel, std::string& parameter, bool adding) CXX11_OVERRIDE;
 };
 
@@ -753,7 +765,7 @@ class CoreExport ModeParser : public fakederef<ModeParser>
 	/** Find the mode handler for a given mode and type.
 	 * @param modeletter mode letter to search for
 	 * @param mt type of mode to search for, user or channel
-	 * @returns a pointer to a ModeHandler class, or NULL of there isnt a handler for the given mode
+	 * @returns a pointer to a ModeHandler class, or NULL of there isn't a handler for the given mode
 	 */
 	ModeHandler* FindMode(unsigned const char modeletter, ModeType mt);
 
@@ -770,7 +782,7 @@ class CoreExport ModeParser : public fakederef<ModeParser>
 	 */
 	PrefixMode* FindPrefix(unsigned const char pfxletter);
 
-	/** Generates a list of modes, comma seperated by type:
+	/** Generates a list of modes, comma separated by type:
 	 *  1; Listmodes EXCEPT those with a prefix
 	 *  2; Modes that take a param when adding or removing
 	 *  3; Modes that only take a param when adding
