@@ -1,13 +1,19 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
+ *   Copyright (C) 2019 iwalkalone <iwalkalone69@gmail.com>
+ *   Copyright (C) 2013 Adam <Adam@anope.org>
+ *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012-2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2006-2007, 2009 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2003-2008 Craig Edwards <craigedwards@brainbox.cc>
+ *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2006-2007 Oliver Lupton <oliverlupton@gmail.com>
- *   Copyright (C) 2003 randomdan <???@???>
+ *   Copyright (C) 2007-2009 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2007 Oliver Lupton <om@inspircd.org>
+ *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -25,13 +31,11 @@
 
 #pragma once
 
+#include "moduledefs.h"
 #include "dynamic.h"
 #include "base.h"
 #include "ctables.h"
 #include "inspsocket.h"
-#include <string>
-#include <deque>
-#include <sstream>
 #include "timer.h"
 #include "mode.h"
 
@@ -54,61 +58,76 @@ enum ModuleFlags
 	VF_OPTCOMMON = 8
 };
 
+/** The event was explicitly allowed. */
 #define MOD_RES_ALLOW (ModResult(1))
+
+/** The event was not explicitly allowed or denied. */
 #define MOD_RES_PASSTHRU (ModResult(0))
+
+/** The event was explicitly denied. */
 #define MOD_RES_DENY (ModResult(-1))
 
-/** Used to represent an allow/deny module result.
- * Not constructed as an enum because it reverses the value logic of some functions;
- * the compiler will inline accesses to have the same efficiency as integer operations.
- */
-struct ModResult {
-	int res;
-	ModResult() : res(0) {}
-	explicit ModResult(int r) : res(r) {}
-	inline bool operator==(const ModResult& r) const
+/** Represents the result of a module event. */
+class ModResult
+{
+ private:
+	/** The underlying result value. */
+	char result;
+
+ public:
+	/** Creates a new instance of the ModResult class which defaults to MOD_RES_PASSTHRU. */
+	ModResult()
+		: result(0)
 	{
-		return res == r.res;
 	}
-	inline bool operator!=(const ModResult& r) const
+
+	/** Creates a new instance of the ModResult class with the specified value. */
+	explicit ModResult(char res)
+		: result(res)
 	{
-		return res != r.res;
 	}
+
+	/** Determines whether this ModResult has.the same value as \p res */
+	inline bool operator==(const ModResult& res) const
+	{
+		return result == res.result;
+	}
+
+	/** Determines whether this ModResult has.a different value to \p res */
+	inline bool operator!=(const ModResult& res) const
+	{
+		return result != res.result;
+	}
+
+	/** Determines whether a non-MOD_RES_PASSTHRU result has been set. */
 	inline bool operator!() const
 	{
-		return !res;
+		return !result;
 	}
+
+	/** Checks whether the result is an MOD_RES_ALLOW or MOD_RES_PASSTHRU when the default is to allow. */
 	inline bool check(bool def) const
 	{
-		return (res == 1 || (res == 0 && def));
+		return (result == 1 || (result == 0 && def));
 	}
-	/**
-	 * Merges two results, preferring ALLOW to DENY
-	 */
-	inline ModResult operator+(const ModResult& r) const
+
+	/* Merges two results preferring MOD_RES_ALLOW to MOD_RES_DENY. */
+	inline ModResult operator+(const ModResult& res) const
 	{
-		if (res == r.res || r.res == 0)
+		// If the results are identical or the other result is MOD_RES_PASSTHRU
+		// then return this result.
+		if (result == res.result || res.result == 0)
 			return *this;
-		if (res == 0)
-			return r;
-		// they are different, and neither is passthru
+
+		// If this result is MOD_RES_PASSTHRU then return the other result.
+		if (result == 0)
+			return res;
+
+		// Otherwise, they are different, and neither is MOD_RES_PASSTHRU.
 		return MOD_RES_ALLOW;
 	}
 };
 
-/** InspIRCd major version.
- * 1.2 -> 102; 2.1 -> 201; 2.12 -> 212
- */
-#define INSPIRCD_VERSION_MAJ 300
-
-/** InspIRCd API version.
- * If you change any API elements, increment this value. This counter should be
- * reset whenever the major version is changed. Modules can use these two values
- * and numerical comparisons in preprocessor macros if they wish to support
- * multiple versions of InspIRCd in one file.
- */
-#define INSPIRCD_VERSION_API 7
-
 /**
  * This #define allows us to call a method in all
  * loaded modules in a readable simple way, e.g.:
@@ -195,7 +214,7 @@ class CoreExport Version
 	/** Simple module version */
 	Version(const std::string &desc, int flags = VF_NONE);
 
-	/** Complex version information, including linking compatability data */
+	/** Complex version information, including linking compatibility data */
 	Version(const std::string &desc, int flags, const std::string& linkdata);
 };
 
@@ -214,30 +233,85 @@ enum Priority { PRIORITY_FIRST, PRIORITY_LAST, PRIORITY_BEFORE, PRIORITY_AFTER }
  */
 enum Implementation
 {
-	I_OnUserConnect, I_OnUserPreQuit, I_OnUserQuit, I_OnUserDisconnect, I_OnUserJoin, I_OnUserPart,
-	I_OnSendSnotice, I_OnUserPreJoin, I_OnUserPreKick, I_OnUserKick, I_OnOper,
-	I_OnUserPreInvite, I_OnUserInvite, I_OnUserPreMessage, I_OnUserPreNick,
-	I_OnUserPostMessage, I_OnUserMessageBlocked, I_OnMode, I_OnShutdown,
-	I_OnDecodeMetaData, I_OnAcceptConnection, I_OnUserInit, I_OnUserPostInit,
-	I_OnChangeHost, I_OnChangeRealName, I_OnAddLine, I_OnDelLine, I_OnExpireLine,
-	I_OnUserPostNick, I_OnPreMode, I_On005Numeric, I_OnKill, I_OnLoadModule,
-	I_OnUnloadModule, I_OnBackgroundTimer, I_OnPreCommand, I_OnCheckReady, I_OnCheckInvite,
-	I_OnRawMode, I_OnCheckKey, I_OnCheckLimit, I_OnCheckBan, I_OnCheckChannelBan, I_OnExtBanCheck,
-	I_OnPreChangeHost, I_OnPreTopicChange, I_OnConnectionFail,
-	I_OnPostTopicChange, I_OnPostConnect, I_OnPostDeoper,
-	I_OnPreChangeRealName, I_OnUserRegister, I_OnChannelPreDelete, I_OnChannelDelete,
-	I_OnPostOper, I_OnPostCommand, I_OnPostJoin,
-	I_OnBuildNeighborList, I_OnGarbageCollect, I_OnSetConnectClass,
-	I_OnUserMessage, I_OnPassCompare, I_OnNumeric,
-	I_OnPreRehash, I_OnModuleRehash, I_OnChangeIdent, I_OnSetUserIP,
-	I_OnServiceAdd, I_OnServiceDel, I_OnUserWrite,
+	I_On005Numeric,
+	I_OnAcceptConnection,
+	I_OnAddLine,
+	I_OnBackgroundTimer,
+	I_OnBuildNeighborList,
+	I_OnChangeHost,
+	I_OnChangeRealHost,
+	I_OnChangeIdent,
+	I_OnChangeRealName,
+	I_OnChannelDelete,
+	I_OnChannelPreDelete,
+	I_OnCheckBan,
+	I_OnCheckChannelBan,
+	I_OnCheckInvite,
+	I_OnCheckKey,
+	I_OnCheckLimit,
+	I_OnCheckReady,
+	I_OnCommandBlocked,
+	I_OnConnectionFail,
+	I_OnDecodeMetaData,
+	I_OnDelLine,
+	I_OnExpireLine,
+	I_OnExtBanCheck,
+	I_OnGarbageCollect,
+	I_OnKill,
+	I_OnLoadModule,
+	I_OnMode,
+	I_OnModuleRehash,
+	I_OnNumeric,
+	I_OnOper,
+	I_OnPassCompare,
+	I_OnPostCommand,
+	I_OnPostConnect,
+	I_OnPostDeoper,
+	I_OnPostJoin,
+	I_OnPostOper,
+	I_OnPostTopicChange,
+	I_OnPreChangeHost,
+	I_OnPreChangeRealName,
+	I_OnPreCommand,
+	I_OnPreMode,
+	I_OnPreRehash,
+	I_OnPreTopicChange,
+	I_OnRawMode,
+	I_OnSendSnotice,
+	I_OnServiceAdd,
+	I_OnServiceDel,
+	I_OnSetConnectClass,
+	I_OnSetUserIP,
+	I_OnShutdown,
+	I_OnUnloadModule,
+	I_OnUserConnect,
+	I_OnUserDisconnect,
+	I_OnUserInit,
+	I_OnUserInvite,
+	I_OnUserJoin,
+	I_OnUserKick,
+	I_OnUserMessage,
+	I_OnUserMessageBlocked,
+	I_OnUserPart,
+	I_OnUserPostInit,
+	I_OnUserPostMessage,
+	I_OnUserPostNick,
+	I_OnUserPreInvite,
+	I_OnUserPreJoin,
+	I_OnUserPreKick,
+	I_OnUserPreMessage,
+	I_OnUserPreNick,
+	I_OnUserPreQuit,
+	I_OnUserQuit,
+	I_OnUserRegister,
+	I_OnUserWrite,
 	I_END
 };
 
 /** Base class for all InspIRCd modules
  *  This class is the base class for InspIRCd modules. All modules must inherit from this class,
  *  its methods will be called when irc server events occur. class inherited from module must be
- *  instantiated by the ModuleFactory class (see relevent section) for the module to be initialised.
+ *  instantiated by the ModuleFactory class (see relevant section) for the module to be initialised.
  */
 class CoreExport Module : public classbase, public usecountbase
 {
@@ -272,7 +346,7 @@ class CoreExport Module : public classbase, public usecountbase
 	/** Module setup
 	 * \exception ModuleException Throwing this class, or any class derived from ModuleException, causes loading of the module to abort.
 	 */
-	virtual void init() {}
+	virtual void init() { }
 
 	/** Clean up prior to destruction
 	 * If you override, you must call this AFTER your module's cleanup
@@ -284,9 +358,8 @@ class CoreExport Module : public classbase, public usecountbase
 	 */
 	virtual ~Module();
 
-	virtual void Prioritize()
-	{
-	}
+	/** Called when the hooks provided by a module need to be prioritised. */
+	virtual void Prioritize() { }
 
 	/** This method is called when you should reload module specific configuration:
 	 * on boot, on a /REHASH and on module load.
@@ -387,7 +460,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called on rehash.
 	 * This method is called when a user initiates a module-specific rehash. This can be used to do
-	 * expensive operations (such as reloading SSL certificates) that are not executed on a normal
+	 * expensive operations (such as reloading TLS (SSL) certificates) that are not executed on a normal
 	 * rehash for efficiency. A rehash of this type does not reload the core configuration.
 	 *
 	 * @param user The user performing the rehash.
@@ -457,7 +530,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called after a user opers locally.
 	 * This is identical to Module::OnOper(), except it is called after OnOper so that other modules
-	 * can be gauranteed to already have processed the oper-up, for example m_spanningtree has sent
+	 * can be guaranteed to already have processed the oper-up, for example m_spanningtree has sent
 	 * out the OPERTYPE, etc.
 	 * @param user The user who is opering up
 	 * @param opername The name of the oper that the user is opering up to. Only valid locally. Empty string otherwise.
@@ -483,7 +556,7 @@ class CoreExport Module : public classbase, public usecountbase
 	virtual ModResult OnUserPreInvite(User* source,User* dest,Channel* channel, time_t timeout);
 
 	/** Called after a user has been successfully invited to a channel.
-	 * You cannot prevent the invite from occuring using this function, to do that,
+	 * You cannot prevent the invite from occurring using this function, to do that,
 	 * use OnUserPreInvite instead.
 	 * @param source The user who is issuing the INVITE
 	 * @param dest The user being invited
@@ -580,6 +653,13 @@ class CoreExport Module : public classbase, public usecountbase
 	 */
 	virtual void OnChangeHost(User* user, const std::string &newhost);
 
+	/** Called whenever a user's real hostname is changed.
+	 * This event triggers after the host has been set.
+	 * @param user The user whos host is being changed
+	 * @param newhost The new hostname being set
+	 */
+	virtual void OnChangeRealHost(User* user, const std::string& newhost);
+
 	/** Called whenever a user's real name is changed.
 	 * This event triggers after the name has been set.
 	 * @param user The user who's real name is being changed
@@ -650,7 +730,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called when a 005 numeric is about to be output.
 	 * The module should modify the 005 numeric if needed to indicate its features.
-	* @param tokens The 005 map to be modified if neccessary.
+	* @param tokens The 005 map to be modified if necessary.
 	*/
 	virtual void On005Numeric(std::map<std::string, std::string>& tokens);
 
@@ -676,7 +756,7 @@ class CoreExport Module : public classbase, public usecountbase
 	 * for example loaded "m_killwidgets.so" with "m_makewidgets.so". It is highly
 	 * recommended that modules do *NOT* bail if they cannot satisfy dependencies,
 	 * but instead operate under reduced functionality, unless the dependency is
-	 * absolutely neccessary (e.g. a module that extends the features of another
+	 * absolutely necessary (e.g. a module that extends the features of another
 	 * module).
 	 * @param mod A pointer to the new module
 	 */
@@ -689,7 +769,7 @@ class CoreExport Module : public classbase, public usecountbase
 	 * for example loaded "m_killwidgets.so" with "m_makewidgets.so". It is highly
 	 * recommended that modules do *NOT* bail if they cannot satisfy dependencies,
 	 * but instead operate under reduced functionality, unless the dependency is
-	 * absolutely neccessary (e.g. a module that extends the features of another
+	 * absolutely necessary (e.g. a module that extends the features of another
 	 * module).
 	 * @param mod Pointer to the module being unloaded (still valid)
 	 */
@@ -697,18 +777,18 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called once every five seconds for background processing.
 	 * This timer can be used to control timed features. Its period is not accurate
-	 * enough to be used as a clock, but it is gauranteed to be called at least once in
+	 * enough to be used as a clock, but it is guaranteed to be called at least once in
 	 * any five second period, directly from the main loop of the server.
 	 * @param curtime The current timer derived from time(2)
 	 */
 	virtual void OnBackgroundTimer(time_t curtime);
 
 	/** Called whenever any command is about to be executed.
-	 * This event occurs for all registered commands, wether they are registered in the core,
+	 * This event occurs for all registered commands, whether they are registered in the core,
 	 * or another module, and for invalid commands. Invalid commands may only be sent to this
 	 * function when the value of validated is false. By returning 1 from this method you may prevent the
 	 * command being executed. If you do this, no output is created by the core, and it is
-	 * down to your module to produce any output neccessary.
+	 * down to your module to produce any output necessary.
 	 * Note that unless you return 1, you should not destroy any structures (e.g. by using
 	 * InspIRCd::QuitUser) otherwise when the command's handler function executes after your
 	 * method returns, it will be passed an invalid pointer to the user object and crash!)
@@ -722,7 +802,7 @@ class CoreExport Module : public classbase, public usecountbase
 	virtual ModResult OnPreCommand(std::string& command, CommandBase::Params& parameters, LocalUser* user, bool validated);
 
 	/** Called after any command has been executed.
-	 * This event occurs for all registered commands, wether they are registered in the core,
+	 * This event occurs for all registered commands, whether they are registered in the core,
 	 * or another module, but it will not occur for invalid commands (e.g. ones which do not
 	 * exist within the command table). The result code returned by the command handler is
 	 * provided.
@@ -734,6 +814,13 @@ class CoreExport Module : public classbase, public usecountbase
 	 */
 	virtual void OnPostCommand(Command* command, const CommandBase::Params& parameters, LocalUser* user, CmdResult result, bool loop);
 
+	/** Called when a command was blocked before it could be executed.
+	 * @param command The command being executed.
+	 * @param parameters The parameters for the command.
+	 * @param user The user issuing the command.
+	 */
+	virtual void OnCommandBlocked(const std::string& command, const CommandBase::Params& parameters, LocalUser* user);
+
 	/** Called after a user object is initialised and added to the user list.
 	 * When this is called the user has not had their I/O hooks checked or had their initial
 	 * connect class assigned and may not yet have a serialiser. You probably want to use
@@ -772,7 +859,7 @@ class CoreExport Module : public classbase, public usecountbase
 	virtual ModResult OnUserRegister(LocalUser* user);
 
 	/** Called whenever a user joins a channel, to determine if invite checks should go ahead or not.
-	 * This method will always be called for each join, wether or not the channel is actually +i, and
+	 * This method will always be called for each join, whether or not the channel is actually +i, and
 	 * determines the outcome of an if statement around the whole section of invite checking code.
 	 * return 1 to explicitly allow the join to go ahead or 0 to ignore the event.
 	 * @param user The user joining the channel
@@ -795,7 +882,7 @@ class CoreExport Module : public classbase, public usecountbase
 	virtual ModResult OnRawMode(User* user, Channel* chan, ModeHandler* mh, const std::string& param, bool adding);
 
 	/** Called whenever a user joins a channel, to determine if key checks should go ahead or not.
-	 * This method will always be called for each join, wether or not the channel is actually +k, and
+	 * This method will always be called for each join, whether or not the channel is actually +k, and
 	 * determines the outcome of an if statement around the whole section of key checking code.
 	 * if the user specified no key, the keygiven string will be a valid but empty value.
 	 * return 1 to explicitly allow the join to go ahead or 0 to ignore the event.
@@ -807,7 +894,7 @@ class CoreExport Module : public classbase, public usecountbase
 	virtual ModResult OnCheckKey(User* user, Channel* chan, const std::string &keygiven);
 
 	/** Called whenever a user joins a channel, to determine if channel limit checks should go ahead or not.
-	 * This method will always be called for each join, wether or not the channel is actually +l, and
+	 * This method will always be called for each join, whether or not the channel is actually +l, and
 	 * determines the outcome of an if statement around the whole section of channel limit checking code.
 	 * return 1 to explicitly allow the join to go ahead or 0 to ignore the event.
 	 * @param user The user joining the channel
@@ -953,7 +1040,6 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called before a server shuts down.
 	 * @param reason The reason the server is shutting down.
-	 * @param restart Whether the server is restarting.
 	 */
 	virtual void OnShutdown(const std::string& reason);
 };
@@ -1062,17 +1148,17 @@ class CoreExport ModuleManager : public fakederef<ModuleManager>
 	void SetPriority(Module* mod, Priority s);
 
 	/** Attach an event to a module.
-	 * You may later detatch the event with ModuleManager::Detach().
-	 * If your module is unloaded, all events are automatically detatched.
+	 * You may later detach the event with ModuleManager::Detach().
+	 * If your module is unloaded, all events are automatically detached.
 	 * @param i Event type to attach
 	 * @param mod Module to attach event to
 	 * @return True if the event was attached
 	 */
 	bool Attach(Implementation i, Module* mod);
 
-	/** Detatch an event from a module.
+	/** Detach an event from a module.
 	 * This is not required when your module unloads, as the core will
-	 * automatically detatch your module from all events it is attached to.
+	 * automatically detach your module from all events it is attached to.
 	 * @param i Event type to detach
 	 * @param mod Module to detach event from
 	 * @return True if the event was detached
@@ -1178,24 +1264,3 @@ class CoreExport ModuleManager : public fakederef<ModuleManager>
 	 */
 	void DelReferent(ServiceProvider* service);
 };
-
-/** Do not mess with these functions unless you know the C preprocessor
- * well enough to explain why they are needed. The order is important.
- */
-#define MODULE_INIT_STR MODULE_INIT_STR_FN_2(MODULE_INIT_SYM)
-#define MODULE_INIT_STR_FN_2(x) MODULE_INIT_STR_FN_1(x)
-#define MODULE_INIT_STR_FN_1(x) #x
-#define MODULE_INIT_SYM MODULE_INIT_SYM_FN_2(INSPIRCD_VERSION_MAJ, INSPIRCD_VERSION_API)
-#define MODULE_INIT_SYM_FN_2(x,y) MODULE_INIT_SYM_FN_1(x,y)
-#define MODULE_INIT_SYM_FN_1(x,y) inspircd_module_ ## x ## _ ## y
-
-/** This definition is used as shorthand for the various classes
- * and functions needed to make a module loadable by the OS.
- * It defines the class factory and external init_module function.
- */
-#define MODULE_INIT(y) \
-	extern "C" DllExport Module * MODULE_INIT_SYM() \
-	{ \
-		return new y; \
-	} \
-	extern "C" DllExport const char inspircd_src_version[] = INSPIRCD_VERSION;
