@@ -1,9 +1,12 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2015 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2017-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2014-2016, 2018 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2007, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -717,11 +720,9 @@ class ReloadAction : public ActionBase
 		ReloadModule::DataKeeper datakeeper;
 		datakeeper.Save(mod);
 
-		DLLManager* dll = mod->ModuleDLLManager;
 		std::string name = mod->ModuleSourceFile;
 		ServerInstance->Modules->DoSafeUnload(mod);
 		ServerInstance->GlobalCulls.Apply();
-		delete dll;
 		bool result = ServerInstance->Modules->Load(name);
 
 		if (result)
