@@ -1,11 +1,21 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
+ *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
+ *   Copyright (C) 2013-2014, 2016-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
+ *   Copyright (C) 2012-2017 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012-2013, 2016 Adam <Adam@anope.org>
+ *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2008 John Brooks <john.brooks@dereferenced.net>
- *   Copyright (C) 2006-2008 Craig Edwards <craigedwards@brainbox.cc>
+ *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
+ *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2008 John Brooks <special@inspircd.org>
+ *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006 Oliver Lupton <oliverlupton@gmail.com>
+ *   Copyright (C) 2006 Oliver Lupton <om@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -654,12 +664,12 @@ namespace GnuTLS
 
 			Config(const std::string& profilename, ConfigTag* tag)
 				: name(profilename)
-				, certstr(ReadFile(tag->getString("certfile", "cert.pem")))
-				, keystr(ReadFile(tag->getString("keyfile", "key.pem")))
-				, dh(DHParams::Import(ReadFile(tag->getString("dhfile", "dhparams.pem"))))
+				, certstr(ReadFile(tag->getString("certfile", "cert.pem", 1)))
+				, keystr(ReadFile(tag->getString("keyfile", "key.pem", 1)))
+				, dh(DHParams::Import(ReadFile(tag->getString("dhfile", "dhparams.pem", 1))))
 				, priostr(GetPrioStr(profilename, tag))
 				, mindh(tag->getUInt("mindhbits", 1024))
-				, hashstr(tag->getString("hash", "md5"))
+				, hashstr(tag->getString("hash", "md5", 1))
 				, requestclientcert(tag->getBool("requestclientcert", true))
 			{
 				// Load trusted CA and revocation list, if set
@@ -897,7 +907,7 @@ info_done_dealloc:
 		}
 
 		CloseSession();
-		sock->SetError("No SSL session");
+		sock->SetError("No TLS (SSL) session");
 		return -1;
 	}
 
@@ -1281,7 +1291,7 @@ class ModuleSSLGnuTLS : public Module
 	{
 		// First, store all profiles in a new, temporary container. If no problems occur, swap the two
 		// containers; this way if something goes wrong we can go back and continue using the current profiles,
-		// avoiding unpleasant situations where no new SSL connections are possible.
+		// avoiding unpleasant situations where no new TLS (SSL) connections are possible.
 		ProfileList newprofiles;
 
 		ConfigTagList tags = ServerInstance->Config->ConfTags("sslprofile");
@@ -1290,7 +1300,7 @@ class ModuleSSLGnuTLS : public Module
 			// No <sslprofile> tags found, create a profile named "gnutls" from settings in the <gnutls> block
 			const std::string defname = "gnutls";
 			ConfigTag* tag = ServerInstance->Config->ConfValue(defname);
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "No <sslprofile> tags found; using settings from the <gnutls> tag");
+			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "No <sslprofile> tags found; using settings from the deprecated <gnutls> tag");
 
 			try
 			{
@@ -1299,35 +1309,41 @@ class ModuleSSLGnuTLS : public Module
 			}
 			catch (CoreException& ex)
 			{
-				throw ModuleException("Error while initializing the default SSL profile - " + ex.GetReason());
+				throw ModuleException("Error while initializing the default TLS (SSL) profile - " + ex.GetReason());
 			}
 		}
-
-		for (ConfigIter i = tags.first; i != tags.second; ++i)
+		else
 		{
-			ConfigTag* tag = i->second;
-			if (!stdalgo::string::equalsci(tag->getString("provider"), "gnutls"))
-				continue;
-
-			std::string name = tag->getString("name");
-			if (name.empty())
+			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"gnutls\" when configuring TLS (SSL) connections in <bind:ssl> or <link:ssl>");
+			for (ConfigIter i = tags.first; i != tags.second; ++i)
 			{
-				ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "Ignoring <sslprofile> tag without name at " + tag->getTagLocation());
-				continue;
-			}
+				ConfigTag* tag = i->second;
+				if (!stdalgo::string::equalsci(tag->getString("provider"), "gnutls"))
+				{
+					ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "Ignoring non-GnuTLS <sslprofile> tag at " + tag->getTagLocation());
+					continue;
+				}
 
-			reference<GnuTLSIOHookProvider> prov;
-			try
-			{
-				GnuTLS::Profile::Config profileconfig(name, tag);
-				prov = new GnuTLSIOHookProvider(this, profileconfig);
-			}
-			catch (CoreException& ex)
-			{
-				throw ModuleException("Error while initializing SSL profile \"" + name + "\" at " + tag->getTagLocation() + " - " + ex.GetReason());
-			}
+				std::string name = tag->getString("name");
+				if (name.empty())
+				{
+					ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "Ignoring <sslprofile> tag without name at " + tag->getTagLocation());
+					continue;
+				}
 
-			newprofiles.push_back(prov);
+				reference<GnuTLSIOHookProvider> prov;
+				try
+				{
+					GnuTLS::Profile::Config profileconfig(name, tag);
+					prov = new GnuTLSIOHookProvider(this, profileconfig);
+				}
+				catch (CoreException& ex)
+				{
+					throw ModuleException("Error while initializing TLS (SSL) profile \"" + name + "\" at " + tag->getTagLocation() + " - " + ex.GetReason());
+				}
+
+				newprofiles.push_back(prov);
+			}
 		}
 
 		// New profiles are ok, begin using them
@@ -1359,12 +1375,13 @@ class ModuleSSLGnuTLS : public Module
 
 	void OnModuleRehash(User* user, const std::string &param) CXX11_OVERRIDE
 	{
-		if(param != "ssl")
+		if (!irc::equals(param, "tls") && !irc::equals(param, "ssl"))
 			return;
 
 		try
 		{
 			ReadProfiles();
+			ServerInstance->SNO->WriteToSnoMask('a', "TLS (SSL) module GnuTLS rehashed.");
 		}
 		catch (ModuleException& ex)
 		{
@@ -1385,16 +1402,16 @@ class ModuleSSLGnuTLS : public Module
 
 			if ((user) && (user->eh.GetModHook(this)))
 			{
-				// User is using SSL, they're a local user, and they're using one of *our* SSL ports.
-				// Potentially there could be multiple SSL modules loaded at once on different ports.
-				ServerInstance->Users->QuitUser(user, "SSL module unloading");
+				// User is using TLS (SSL), they're a local user, and they're using one of *our* TLS (SSL) ports.
+				// Potentially there could be multiple TLS (SSL) modules loaded at once on different ports.
+				ServerInstance->Users->QuitUser(user, "GnuTLS module unloading");
 			}
 		}
 	}
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides SSL support via GnuTLS", VF_VENDOR);
+		return Version("Allows TLS (SSL) encrypted connections using the GnuTLS library.", VF_VENDOR);
 	}
 
 	ModResult OnCheckReady(LocalUser* user) CXX11_OVERRIDE
