@@ -1,9 +1,13 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2005-2007 Craig Edwards <craigedwards@brainbox.cc>
+ *   Copyright (C) 2013, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2014 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2009 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2006-2007, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -136,7 +140,7 @@ private:
 
 			insp::flat_set<int> ports;
 			const std::string portlist = tag->getString("ports");
-			if (!ports.empty())
+			if (!portlist.empty())
 			{
 				irc::portparser portrange(portlist, false);
 				while (int port = portrange.GetToken())
@@ -172,7 +176,9 @@ private:
 			}
 		}
 
-		const std::string hmap = ServerInstance->Config->ConfValue("hostname")->getString("charmap", "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz.-_/0123456789");
+		ConfigTag* tag = ServerInstance->Config->ConfValue("hostname");
+		const std::string hmap = tag->getString("charmap", "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz.-_/0123456789", 1);
+
 		hostmap.reset();
 		for (std::string::const_iterator iter = hmap.begin(); iter != hmap.end(); ++iter)
 			hostmap.set(static_cast<unsigned char>(*iter));
@@ -181,7 +187,7 @@ private:
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides rule-based masking of user hostnames", VF_VENDOR);
+		return Version("Allows the server administrator to define custom rules for applying hostnames to users.", VF_VENDOR);
 	}
 
 	void OnUserConnect(LocalUser* user) CXX11_OVERRIDE
