@@ -1,10 +1,13 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2006, 2008 Craig Edwards <craigedwards@brainbox.cc>
+ *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
+ *   Copyright (C) 2013, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2006, 2008 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -43,7 +46,7 @@ class ModuleNamesX
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides the NAMESX (CAP multi-prefix) capability", VF_VENDOR);
+		return Version("Provides the IRCv3 multi-prefix client capability.", VF_VENDOR);
 	}
 
 	void On005Numeric(std::map<std::string, std::string>& tokens) CXX11_OVERRIDE
@@ -63,7 +66,7 @@ class ModuleNamesX
 		 */
 		if (command == "PROTOCTL")
 		{
-			if ((parameters.size()) && (!strcasecmp(parameters[0].c_str(),"NAMESX")))
+			if (!parameters.empty() && irc::equals(parameters[0], "NAMESX"))
 			{
 				cap.set(user, true);
 				return MOD_RES_DENY;
