@@ -1,10 +1,13 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
+ *   Copyright (C) 2013, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2013 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
+ *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2004, 2006 Craig Edwards <craigedwards@brainbox.cc>
+ *   Copyright (C) 2006, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -28,26 +31,16 @@ enum
 	ERR_CANTJOINOPERSONLY = 520
 };
 
-class OperChans : public SimpleChannelModeHandler
-{
- public:
-	/* This is an oper-only mode */
-	OperChans(Module* Creator) : SimpleChannelModeHandler(Creator, "operonly", 'O')
-	{
-		oper = true;
-	}
-};
-
 class ModuleOperChans : public Module
 {
  private:
-	OperChans oc;
+	SimpleChannelModeHandler oc;
 	std::string space;
 	std::string underscore;
 
  public:
 	ModuleOperChans()
-		: oc(this)
+		: oc(this, "operonly", 'O', true)
 		, space(" ")
 		, underscore("_")
 	{
@@ -94,7 +87,7 @@ class ModuleOperChans : public Module
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides support for oper-only channels via channel mode +O and extban 'O'", VF_VENDOR);
+		return Version("Adds channel mode O (operonly) which prevents non-server operators from joining the channel.", VF_VENDOR);
 	}
 };
 
