@@ -1,10 +1,13 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2005, 2007 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2005-2006 Craig Edwards <craigedwards@brainbox.cc>
- *   Copyright (C) 2004 Christopher Hall <typobox43@gmail.com>
+ *   Copyright (C) 2013, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2013, 2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
+ *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
+ *   Copyright (C) 2007, 2009 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -42,7 +45,8 @@ class CommandOpermotd : public Command
 
 	CommandOpermotd(Module* Creator) : Command(Creator,"OPERMOTD", 0, 1)
 	{
-		flags_needed = 'o'; syntax = "[<servername>]";
+		flags_needed = 'o';
+		syntax = "[<servername>]";
 	}
 
 	CmdResult Handle(User* user, const Params& parameters) CXX11_OVERRIDE
@@ -72,7 +76,7 @@ class CommandOpermotd : public Command
 
 		for (file_cache::const_iterator i = opermotd.begin(); i != opermotd.end(); ++i)
 		{
-			user->WriteRemoteNumeric(RPL_OMOTD, InspIRCd::Format("- %s", i->c_str()));
+			user->WriteRemoteNumeric(RPL_OMOTD, InspIRCd::Format(" %s", i->c_str()));
 		}
 
 		user->WriteRemoteNumeric(RPL_ENDOFOMOTD, "End of OPERMOTD");
@@ -93,7 +97,7 @@ class ModuleOpermotd : public Module
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Shows a message to opers after oper-up and adds the OPERMOTD command", VF_VENDOR | VF_OPTCOMMON);
+		return Version("Adds the /OPERMOTD command which adds a special message of the day for server operators.", VF_VENDOR | VF_OPTCOMMON);
 	}
 
 	void OnOper(User* user, const std::string &opertype) CXX11_OVERRIDE
@@ -110,7 +114,7 @@ class ModuleOpermotd : public Module
 
 		try
 		{
-			FileReader reader(conf->getString("file", "opermotd"));
+			FileReader reader(conf->getString("file", "opermotd", 1));
 			cmd.opermotd = reader.GetVector();
 			InspIRCd::ProcessColors(cmd.opermotd);
 		}
