@@ -1,11 +1,12 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2013, 2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2007-2008 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2003, 2006 Craig Edwards <craigedwards@brainbox.cc>
- *   Copyright (C) 2005 Craig McLure <craig@chatspike.net>
+ *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -36,7 +37,7 @@ class ModuleRandQuote : public Module
 		ConfigTag* conf = ServerInstance->Config->ConfValue("randquote");
 		prefix = conf->getString("prefix");
 		suffix = conf->getString("suffix");
-		FileReader reader(conf->getString("file", "quotes"));
+		FileReader reader(conf->getString("file", "quotes", 1));
 		quotes = reader.GetVector();
 	}
 
@@ -51,7 +52,7 @@ class ModuleRandQuote : public Module
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides random quotes on connect", VF_VENDOR);
+		return Version("Allows random quotes to be sent to users when they connect to the server.", VF_VENDOR);
 	}
 };
 
