@@ -1,9 +1,12 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2013, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2012 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
+ *   Copyright (C) 2007 John Brooks <special@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2004-2005 Craig Edwards <craigedwards@brainbox.cc>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -20,45 +23,58 @@
 
 
 #include "inspircd.h"
+#include "modules/ircv3.h"
+#include "modules/ircv3_replies.h"
 
-
-
-class CommandSetname : public Command
+class CommandSetName : public SplitCommand
 {
+private:
+	IRCv3::Replies::Fail fail;
+
  public:
+	Cap::Capability cap;
 	bool notifyopers;
-	CommandSetname(Module* Creator) : Command(Creator,"SETNAME", 1, 1)
+
+	CommandSetName(Module* Creator)
+		: SplitCommand(Creator, "SETNAME", 1, 1)
+		, fail(Creator)
+		, cap(Creator, "setname")
 	{
 		allow_empty_last_param = false;
 		syntax = ":<realname>";
 	}
 
-	CmdResult Handle(User* user, const Params& parameters) CXX11_OVERRIDE
+	CmdResult HandleLocal(LocalUser* user, const Params& parameters) CXX11_OVERRIDE
 	{
 		if (parameters[0].size() > ServerInstance->Config->Limits.MaxReal)
 		{
-			user->WriteNotice("*** SETNAME: Real name is too long");
+			fail.SendIfCap(user, cap, this, "INVALID_REALNAME", "Real name is too long");
 			return CMD_FAILURE;
 		}
 
-		if (user->ChangeRealName(parameters[0]))
+		if (!user->ChangeRealName(parameters[0]))
 		{
-			if (notifyopers)
-				ServerInstance->SNO->WriteGlobalSno('a', "%s used SETNAME to change their real name to '%s'",
-					user->nick.c_str(), parameters[0].c_str());
+			fail.SendIfCap(user, cap, this, "CANNOT_CHANGE_REALNAME", "Unable to change your real name");
+			return CMD_FAILURE;
 		}
 
+		if (notifyopers)
+			ServerInstance->SNO->WriteGlobalSno('a', "%s used SETNAME to change their real name to '%s'",
+				user->nick.c_str(), parameters[0].c_str());
 		return CMD_SUCCESS;
 	}
 };
 
-
 class ModuleSetName : public Module
 {
-	CommandSetname cmd;
+ private:
+	CommandSetName cmd;
+	ClientProtocol::EventProvider setnameevprov;
+
  public:
 	ModuleSetName()
 		: cmd(this)
+		, setnameevprov(this, "SETNAME")
 	{
 	}
 
@@ -74,9 +90,20 @@ class ModuleSetName : public Module
 		cmd.notifyopers = tag->getBool("notifyopers", !operonly);
 	}
 
+	void OnChangeRealName(User* user, const std::string& real) CXX11_OVERRIDE
+	{
+		if (!(user->registered & REG_NICKUSER))
+			return;
+
+		ClientProtocol::Message msg("SETNAME", user);
+		msg.PushParamRef(real);
+		ClientProtocol::Event protoev(setnameevprov, msg);
+		IRCv3::WriteNeighborsWithCap(user, protoev, cmd.cap, true);
+	}
+
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides the SETNAME command", VF_VENDOR);
+		return Version("Adds the /SETNAME command which allows users to change their real name (gecos).", VF_VENDOR);
 	}
 };
 
