@@ -1,7 +1,10 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2019 Peter Powell <petpow@saberuk.com>
+ *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
+ *   Copyright (C) 2019 iwalkalone <iwalkalone69@gmail.com>
+ *   Copyright (C) 2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -473,7 +476,6 @@ class ModuleSilence
 					flag = SilenceEntry::SF_PRIVMSG_CHANNEL;
 
 				return BuildChannelExempts(user, target.Get<Channel>(), flag, details.exemptions);
-				break;
 			}
 			case MessageTarget::TYPE_USER:
 			{
@@ -514,7 +516,7 @@ class ModuleSilence
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides support for blocking users with the SILENCE command", VF_OPTCOMMON | VF_VENDOR);
+		return Version("Adds the /SILENCE command which allows users to ignore other users on server-side.", VF_OPTCOMMON | VF_VENDOR);
 	}
 };
 
