@@ -1,9 +1,13 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2007-2008 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2007 Craig Edwards <craigedwards@brainbox.cc>
+ *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
+ *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2007 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -36,13 +40,18 @@
  * and only do minor initialization tasks ourselves.
  */
 TreeSocket::TreeSocket(Link* link, Autoconnect* myac, const irc::sockets::sockaddrs& dest)
-	: linkID(link->Name), LinkState(CONNECTING), MyRoot(NULL), proto_version(0)
-	, burstsent(false), age(ServerInstance->Time())
+	: linkID(link->Name)
+	, LinkState(CONNECTING)
+	, MyRoot(NULL)
+	, proto_version(0)
+	, burstsent(false)
+	, age(ServerInstance->Time())
 {
 	capab = new CapabData;
 	capab->link = link;
 	capab->ac = myac;
 	capab->capab_phase = 0;
+	capab->remotesa = dest;
 
 	irc::sockets::sockaddrs bind;
 	memset(&bind, 0, sizeof(bind));
@@ -73,11 +82,16 @@ TreeSocket::TreeSocket(Link* link, Autoconnect* myac, const irc::sockets::sockad
  */
 TreeSocket::TreeSocket(int newfd, ListenSocket* via, irc::sockets::sockaddrs* client, irc::sockets::sockaddrs* server)
 	: BufferedSocket(newfd)
-	, linkID("inbound from " + client->addr()), LinkState(WAIT_AUTH_1), MyRoot(NULL), proto_version(0)
-	, burstsent(false), age(ServerInstance->Time())
+	, linkID("inbound from " + client->addr())
+	, LinkState(WAIT_AUTH_1)
+	, MyRoot(NULL)
+	, proto_version(0)
+	, burstsent(false)
+	, age(ServerInstance->Time())
 {
 	capab = new CapabData;
 	capab->capab_phase = 0;
+	capab->remotesa = *client;
 
 	for (ListenSocket::IOHookProvList::iterator i = via->iohookprovs.begin(); i != via->iohookprovs.end(); ++i)
 	{
