@@ -1,7 +1,15 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
+ *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
+ *   Copyright (C) 2014 Justin Crawford <Justasic@Gmail.com>
+ *   Copyright (C) 2013, 2015, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2013 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2012, 2014 Adam <Adam@anope.org>
+ *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
+ *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -45,7 +53,7 @@ class ModuleXLineDB
 		 * 		...and so is discarding all current in-memory XLines for the ones in the database.
 		 */
 		ConfigTag* Conf = ServerInstance->Config->ConfValue("xlinedb");
-		xlinedbpath = ServerInstance->Config->Paths.PrependData(Conf->getString("filename", "xline.db"));
+		xlinedbpath = ServerInstance->Config->Paths.PrependData(Conf->getString("filename", "xline.db", 1));
 		SetInterval(Conf->getDuration("saveperiod", 5));
 
 		// Read xlines before attaching to events
@@ -148,7 +156,7 @@ class ModuleXLineDB
 #ifdef _WIN32
 		remove(xlinedbpath.c_str());
 #endif
-		// Use rename to move temporary to new db - this is guarenteed not to fuck up, even in case of a crash.
+		// Use rename to move temporary to new db - this is guaranteed not to fuck up, even in case of a crash.
 		if (rename(xlinenewdbpath.c_str(), xlinedbpath.c_str()) < 0)
 		{
 			ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Cannot replace old database \"%s\" with new database \"%s\"! %s (%d)", xlinedbpath.c_str(), xlinenewdbpath.c_str(), strerror(errno), errno);
@@ -228,7 +236,7 @@ class ModuleXLineDB
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Provides the ability to store X-lines in a database file", VF_VENDOR);
+		return Version("Allows X-lines to be saved and reloaded on restart.", VF_VENDOR);
 	}
 };
 
